@@ -1,6 +1,6 @@
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.db.transaction import commit_on_success
+from django.db import transaction
 from django.http import HttpResponseNotFound, HttpResponse, HttpResponseBadRequest, HttpResponseRedirect
 from django.utils.translation import ugettext_lazy as _
 from polymorphic.admin import PolymorphicParentModelAdmin, PolymorphicModelChoiceForm
@@ -16,6 +16,12 @@ except ImportError:
     from django.conf.urls.defaults import url
 
 
+try:
+    transaction_atomic = transaction.atomic
+except AttributeError:
+    transaction_atomic = transaction.commit_on_success
+
+
 class NodeTypeChoiceForm(PolymorphicModelChoiceForm):
     type_label = _("Node type")
 
@@ -156,7 +162,7 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
         return reverse('admin:{0}_{1}_moved'.format(*info))
 
 
-    @commit_on_success
+    @transaction_atomic
     def api_node_moved_view(self, request):
         """
         Update the position of a node, from a API request.
@@ -199,8 +205,6 @@ class PolymorphicMPTTParentModelAdmin(PolymorphicParentModelAdmin, MPTTModelAdmi
 
         # Some packages depend on calling .save() or post_save signal after updating a model.
         # This is required by django-fluent-pages for example to update the URL caches.
-        # Make sure the updated version (with new parent_id/lft/rgt fields is fetched)
-        moved = self.model.objects.get(pk=moved_id)
         moved.save()
 
         # Report back to client.
